canossa invisible screen engine
===============================

Install
-------

via github ::

    $ git clone https://github.com/saitoha/canossa.git
    $ cd canossa
    $ python setup.py install

or via pip ::

    $ pip install canossa


Usage
-----

Comming soon.

Dependency
----------

 - wcwidth.py
   https://svn.wso2.org/repos/wso2/carbon/platform/trunk/dependencies/cassandra/pylib/cqlshlib/wcwidth.py
   (Licensed under Apache License 2.0)

 - TFF - Terminal Filter Framework
   https://github.com/saitoha/tff

